@@ -26,9 +26,18 @@ INVALIDPARAMETER = 'InvalidParameter'
 # 参数冲突。
 INVALIDPARAMETER_CONFLICTPARAMETER = 'InvalidParameter.ConflictParameter'
 
+# OutputCOSBucketUrl 无效。
+INVALIDPARAMETER_INVALIDOUTPUTCOSBUCKETURL = 'InvalidParameter.InvalidOutputCOSBucketUrl'
+
+# OutputCOSKeyPrefix 无效。
+INVALIDPARAMETER_INVALIDOUTPUTCOSKEYPREFIX = 'InvalidParameter.InvalidOutputCOSKeyPrefix'
+
 # 参数取值错误。
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
+# Agent不支持此命令类型。
+INVALIDPARAMETERVALUE_AGENTUNSUPPORTEDCOMMANDTYPE = 'InvalidParameterValue.AgentUnsupportedCommandType'
+
 # Command 内容无效。
 INVALIDPARAMETERVALUE_COMMANDCONTENTINVALID = 'InvalidParameterValue.CommandContentInvalid'
 
@@ -59,6 +68,9 @@ INVALIDPARAMETERVALUE_INVALIDINVOCATIONID = 'InvalidParameterValue.InvalidInvoca
 # 不合法的执行任务ID。
 INVALIDPARAMETERVALUE_INVALIDINVOCATIONTASKID = 'InvalidParameterValue.InvalidInvocationTaskId'
 
+# InvokerId 无效。
+INVALIDPARAMETERVALUE_INVALIDINVOKERID = 'InvalidParameterValue.InvalidInvokerId'
+
 # 命令执行路径不合法。
 INVALIDPARAMETERVALUE_INVALIDWORKINGDIRECTORY = 'InvalidParameterValue.InvalidWorkingDirectory'
 
@@ -68,6 +80,9 @@ INVALIDPARAMETERVALUE_LACKOFPARAMETERINFO = 'InvalidParameterValue.LackOfParamet
 # 未提供 Parameters 信息。
 INVALIDPARAMETERVALUE_LACKOFPARAMETERS = 'InvalidParameterValue.LackOfParameters'
 
+# 超过参数限制。
+INVALIDPARAMETERVALUE_LIMITEXCEEDED = 'InvalidParameterValue.LimitExceeded'
+
 # 未启用自定义参数功能。
 INVALIDPARAMETERVALUE_PARAMETERDISABLED = 'InvalidParameterValue.ParameterDisabled'
 
